@@ -107,6 +107,9 @@ INVALIDPARAMETERVALUE_ERRORTASKNOTEXIST = 'InvalidParameterValue.ErrorTaskNotExi
 # 固件已经存在。
 INVALIDPARAMETERVALUE_FIRMWAREALREADYEXIST = 'InvalidParameterValue.FirmwareAlreadyExist'
 
+# 转发重定向被拒绝。
+INVALIDPARAMETERVALUE_FORWARDREDIRECTDENIED = 'InvalidParameterValue.ForwardRedirectDenied'
+
 # SQL语句含有非法字符。
 INVALIDPARAMETERVALUE_INVALIDSQL = 'InvalidParameterValue.InvalidSQL'
 
@@ -185,6 +188,9 @@ INVALIDPARAMETERVALUE_PROJECTPARMSERROR = 'InvalidParameterValue.ProjectParmsErr
 # 规则数量超过限制。
 INVALIDPARAMETERVALUE_RULENUMBERBEYONDLIMIT = 'InvalidParameterValue.RuleNumberBeyondLimit'
 
+# Topic已存在。
+INVALIDPARAMETERVALUE_TOPICPOLICYALREADYEXIST = 'InvalidParameterValue.TopicPolicyAlreadyExist'
+
 # 规则已存在。
 INVALIDPARAMETERVALUE_TOPICRULEALREADYEXIST = 'InvalidParameterValue.TopicRuleAlreadyExist'
 
@@ -266,6 +272,9 @@ RESOURCENOTFOUND_PRODUCTNOTEXIST = 'ResourceNotFound.ProductNotExist'
 # 产品或设备不存在。
 RESOURCENOTFOUND_PRODUCTORDEVICENOTEXIST = 'ResourceNotFound.ProductOrDeviceNotExist'
 
+# 产品资源不存在。
+RESOURCENOTFOUND_PRODUCTRESOURCENOTEXIST = 'ResourceNotFound.ProductResourceNotExist'
+
 # 项目不存在。
 RESOURCENOTFOUND_PROJECTNOTEXIST = 'ResourceNotFound.ProjectNotExist'
 
